# Country Database
A comprehensive repository of global country details, including country codes, ISD codes, currency codes, and more. 

![country-database](docs/images/country-database.png)

## 🌐Country Codes
- Alpha2Code
- Alpha3Code
- NumericCode
  
_**Source:** [ISO 3166 - 1](https://en.wikipedia.org/wiki/ISO_3166-1)_

## 🌍Region Details
- Continent
- Capital

_**Source:** [Wikipedia](https://en.wikipedia.org/wiki/List_of_national_capitals)_
  
- RegionName
- RegionCode
- SubRegionName
- SubRegionCode
- IntermediateRegionName
- IntermediateRegionCode

_**Source:** [UN M49](https://unstats.un.org/unsd/methodology/m49/overview/)_

## 🔗TLD
- TopLevelDomain

_**Source:** [IANA](https://www.iana.org/domains/root/db)_

## ☎️Calling Codes
- CallingCode

_**Source:** [ITU](https://www.itu.int/en/ITU-T/Pages/default.aspx)_

## 💲Currency Codes
- CurrencyCode
- CurrencyNumber
- CurrencyName

_**Source:** [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217)_

## 🚩Flag
- FlagEmoji
- FlagUnicode
- FlagImage [ToDo]

_**Source:** [Openmoji](https://openmoji.org/library/)_

## ⚖️License
This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.
